@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/12/17 12:33
+Date: 2021/4/26 12:33
 Desc: 河北省空气质量预报信息发布系统
 http://110.249.223.67/publish/
 每日 17 时发布
@@ -25,7 +25,7 @@ def air_quality_hebei(city: str = "唐山市") -> pd.DataFrame:
     """
     河北省空气质量预报信息发布系统-空气质量预报, 未来 6 天
     http://110.249.223.67/publish/
-    :param city: ['石家庄市', '唐山市', '秦皇岛市', '邯郸市', '邢台市', '保定市', '张家口市', '承德市', '沧州市', '廊坊市', '衡水市', '辛集市', '定州市']
+    :param city: choice of {'石家庄市', '唐山市', '秦皇岛市', '邯郸市', '邢台市', '保定市', '张家口市', '承德市', '沧州市', '廊坊市', '衡水市', '辛集市', '定州市'}
     :type city: str
     :return: city = "", 返回所有地区的数据; city="唐山市", 返回唐山市的数据
     :rtype: pandas.DataFrame
@@ -38,7 +38,7 @@ def air_quality_hebei(city: str = "唐山市") -> pd.DataFrame:
         "CityName"
     ].tolist()
     outer_df = pd.DataFrame()
-    for i in tqdm(range(1, 7)):
+    for i in tqdm(range(1, 7), leave=False):
         inner_df = pd.DataFrame(
             [item[f"Date{i}"] for item in json_data["cityPublishDatas"]],
             index=city_list,
