@@ -24,14 +24,21 @@ def stock_zh_index_hist_csindex(symbol: str = "H30374") -> pd.DataFrame:
         "earnings_performance": "5年",
         "data_type": "json"
     }
-    r = requests.get(url, params=params)
+    headers = {
+        'Host': 'www.csindex.com.cn',
+        'Referer': f'http://www.csindex.com.cn/zh-CN/indices/index-detail/{symbol}',
+        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36'
+    }
+    r = requests.get(url, params=params, headers=headers)
+    r.encoding = 'utf-8-sig'
     data_json = r.json()
-    data_df = pd.DataFrame(data_json)[["tradedate", "tclose"]]
-    data_df["tradedate"] = pd.to_datetime(data_df["tradedate"])
-    data_df.columns = ["date", "close"]
-    return data_df
+    temp_df = pd.DataFrame(data_json)[["tradedate", "tclose"]]
+    temp_df["tradedate"] = pd.to_datetime(temp_df["tradedate"]).dt.date
+    temp_df.columns = ["date", "close"]
+    temp_df['close'] = pd.to_numeric(temp_df['close'])
+    return temp_df
 
 
 if __name__ == "__main__":
-    stock_zh_index_hist_csindex_df = stock_zh_index_hist_csindex(symbol="H30374")
+    stock_zh_index_hist_csindex_df = stock_zh_index_hist_csindex(symbol="H30533")
     print(stock_zh_index_hist_csindex_df)
