@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/10/17 18:11
+Date: 2021/1/29 15:11
 Desc: 新浪财经-股票期权
 https://stock.finance.sina.com.cn/option/quotes.html
 期权-中金所-沪深300指数
@@ -22,8 +22,8 @@ import pandas as pd
 # 期权-中金所-沪深300指数
 def option_sina_cffex_hs300_list() -> Dict[str, List[str]]:
     """
-    中金所-沪深300指数-所有合约, 返回的第一个合约为主力合约
-    目前中金所只有 沪深300指数
+    新浪财经-中金所-沪深300指数-所有合约, 返回的第一个合约为主力合约
+    目前新浪财经-中金所只有 沪深300指数 一个品种的数据
     :return: 中金所-沪深300指数-所有合约
     :rtype: dict
     """
@@ -31,64 +31,64 @@ def option_sina_cffex_hs300_list() -> Dict[str, List[str]]:
     r = requests.get(url)
     soup = BeautifulSoup(r.text, "lxml")
     symbol = soup.find(attrs={"id": "option_symbol"}).find("li").text
-    contract = [
-        item.text for item in soup.find(attrs={"id": "option_suffix"}).find_all("li")
-    ]
+    temp_attr = soup.find(attrs={"id": "option_suffix"}).find_all("li")
+    contract = [item.text for item in temp_attr]
     return {symbol: contract}
 
 
-def option_sina_cffex_hs300_spot(contract: str = "io2004") -> pd.DataFrame:
+def option_sina_cffex_hs300_spot(contract: str = "io2104") -> pd.DataFrame:
     """
     中金所-沪深300指数-指定合约-实时行情
-    :param contract: 合约代码, 用 option_sina_cffex_hs300_list 函数查看
+    https://stock.finance.sina.com.cn/futures/view/optionsCffexDP.php
+    :param contract: 合约代码; 用 option_sina_cffex_hs300_list 函数查看
     :type contract: str
     :return: 中金所-沪深300指数-指定合约-看涨看跌实时行情
     :rtype: pd.DataFrame
     """
     url = "https://stock.finance.sina.com.cn/futures/api/openapi.php/OptionService.getOptionData"
-    payload = {
+    params = {
         "type": "futures",
         "product": "io",
         "exchange": "cffex",
         "pinzhong": contract,
     }
-    r = requests.get(url, params=payload)
+    r = requests.get(url, params=params)
     data_text = r.text
     data_json = json.loads(data_text[data_text.find("{") : data_text.rfind("}") + 1])
     option_call_df = pd.DataFrame(
         data_json["result"]["data"]["up"],
         columns=[
-            "call_买量",
-            "call_买价",
-            "call_最新价",
-            "call_卖价",
-            "call_卖量",
-            "call_持仓量",
-            "call_涨跌",
-            "call_行权价",
-            "call_标识",
+            "看涨合约_买量",
+            "看涨合约_买价",
+            "看涨合约_最新价",
+            "看涨合约_卖价",
+            "看涨合约_卖量",
+            "看涨合约_持仓量",
+            "看涨合约_涨跌",
+            "行权价",
+            "看涨合约_标识",
         ],
     )
     option_put_df = pd.DataFrame(
         data_json["result"]["data"]["down"],
         columns=[
-            "put_买量",
-            "put_买价",
-            "put_最新价",
-            "put_卖价",
-            "put_卖量",
-            "put_持仓量",
-            "put_涨跌",
-            "put_标识",
+            "看跌合约_买量",
+            "看跌合约_买价",
+            "看跌合约_最新价",
+            "看跌合约_卖价",
+            "看跌合约_卖量",
+            "看跌合约_持仓量",
+            "看跌合约_涨跌",
+            "看跌合约_标识",
         ],
     )
-    data_df = pd.concat([option_call_df, option_put_df], axis=1).iloc[:, :-1]
+    data_df = pd.concat([option_call_df, option_put_df], axis=1)
     return data_df
 
 
-def option_sina_cffex_hs300_daily(contract: str = "io2004C4450") -> pd.DataFrame:
+def option_sina_cffex_hs300_daily(contract: str = "io2103C4850") -> pd.DataFrame:
     """
-    中金所-沪深300指数-指定合约-日频行情
+    新浪财经-中金所-沪深300指数-指定合约-日频行情
     :param contract: 具体合约代码(包括看涨和看跌标识), 可以通过 option_sina_cffex_hs300_spot 中的 call_标识 获取
     :type contract: str
     :return: 日频率数据
@@ -98,11 +98,11 @@ def option_sina_cffex_hs300_daily(contract: str = "io2004C4450") -> pd.DataFrame
     month = datetime.datetime.now().month
     day = datetime.datetime.now().day
     url = f"https://stock.finance.sina.com.cn/futures/api/jsonp.php/var%20_{contract}{year}_{month}_{day}=/FutureOptionAllService.getOptionDayline"
-    payload = {"symbol": contract}
-    r = requests.get(url, params=payload)
+    params = {"symbol": contract}
+    r = requests.get(url, params=params)
     data_text = r.text
     data_df = pd.DataFrame(
-        eval(data_text[data_text.find("["): data_text.rfind("]") + 1])
+        eval(data_text[data_text.find("[") : data_text.rfind("]") + 1])
     )
     data_df.columns = ["open", "high", "low", "close", "volume", "date"]
     return data_df
@@ -111,7 +111,8 @@ def option_sina_cffex_hs300_daily(contract: str = "io2004C4450") -> pd.DataFrame
 # 期权-上交所-50ETF
 def option_sina_sse_list(symbol: str = "50ETF", exchange: str = "null") -> List[str]:
     """
-    期权-上交所-50ETF-合约到期月份列表
+    新浪财经-期权-上交所-50ETF-合约到期月份列表
+    https://stock.finance.sina.com.cn/option/quotes.html
     :param symbol: 50ETF or 300ETF
     :type symbol: str
     :param exchange: null
@@ -119,19 +120,19 @@ def option_sina_sse_list(symbol: str = "50ETF", exchange: str = "null") -> List[
     :return: 合约到期时间
     :rtype: list
     """
-    url = (
-        f"http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getStockName?"
-        f"exchange={exchange}&cate={symbol}"
-    )
-    date_list = requests.get(url).json()["result"]["data"]["contractMonth"]
+    url = "http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getStockName"
+    params = {"exchange": f"{exchange}", "cate": f"{symbol}"}
+    r = requests.get(url, params=params)
+    data_json = r.json()
+    date_list = data_json["result"]["data"]["contractMonth"]
     return ["".join(i.split("-")) for i in date_list][1:]
 
 
 def option_sina_sse_expire_day(
-    trade_date: str = "202002", symbol="50ETF", exchange="null"
+    trade_date: str = "202102", symbol: str = "50ETF", exchange: str = "null"
 ) -> Tuple[str, int]:
     """
-    获取指定到期月份指定品种的剩余到期时间
+    指定到期月份指定品种的剩余到期时间
     :param trade_date: 到期月份: 202002, 20203, 20206, 20209
     :type trade_date: str
     :param symbol: 50ETF or 300ETF
@@ -141,25 +142,33 @@ def option_sina_sse_expire_day(
     :return: (到期时间, 剩余时间)
     :rtype: tuple
     """
-    url = (
-        f"http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getRemainderDay?"
-        f"exchange={exchange}&cate={symbol}&date={trade_date[:4]}-{trade_date[4:]}"
-    )
-    data = requests.get(url).json()["result"]["data"]
+    url = "http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getRemainderDay"
+    params = {
+        "exchange": f"{exchange}",
+        "cate": f"{symbol}",
+        "date": f"{trade_date[:4]}-{trade_date[4:]}",
+    }
+    r = requests.get(url, params=params)
+    data_json = r.json()
+    data = data_json["result"]["data"]
     if int(data["remainderDays"]) < 0:
-        url = (
-            f"http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getRemainderDay?"
-            f"exchange={exchange}&cate={'XD' + symbol}&date={trade_date[:4]}-{trade_date[4:]}"
-        )
-        data = requests.get(url).json()["result"]["data"]
+        url = "http://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionService.getRemainderDay"
+        params = {
+            "exchange": f"{exchange}",
+            "cate": f"{'XD' + symbol}",
+            "date": f"{trade_date[:4]}-{trade_date[4:]}",
+        }
+        r = requests.get(url, params=params)
+        data_json = r.json()
+        data = data_json["result"]["data"]
     return data["expireDay"], int(data["remainderDays"])
 
 
 def option_sina_sse_codes(
-    trade_date: str = "202002", underlying: str = "510300"
+    trade_date: str = "202102", underlying: str = "510300"
 ) -> Tuple[List[str], List[str]]:
     """
-    获取上海证券交易所所有看涨和看跌合约的代码
+    上海证券交易所所有看涨和看跌合约的代码
     :param trade_date: 期权到期月份
     :type trade_date: "202002"
     :param underlying: 标的产品代码 华夏上证 50ETF: 510050 or 华泰柏瑞沪深 300ETF: 510300
@@ -173,9 +182,13 @@ def option_sina_sse_codes(
     url_down = "".join(
         ["http://hq.sinajs.cn/list=OP_DOWN_", underlying, str(trade_date)[-4:]]
     )
-    data_up = requests.get(url_up).text.replace('"', ",").split(",")
+    r = requests.get(url_up)
+    data_text = r.text
+    data_up = data_text.replace('"', ",").split(",")
     codes_up = [i[7:] for i in data_up if i.startswith("CON_OP_")]
-    data_down = requests.get(url_down).text.replace('"', ",").split(",")
+    r = requests.get(url_down)
+    data_text = r.text
+    data_down = data_text.replace('"', ",").split(",")
     codes_down = [i[7:] for i in data_down if i.startswith("CON_OP_")]
     return codes_up, codes_down
 
@@ -189,7 +202,8 @@ def option_sina_sse_spot_price(code: str = "10002273") -> pd.DataFrame:
     :rtype: pandas.DataFrame
     """
     url = f"http://hq.sinajs.cn/list=CON_OP_{code}"
-    data_text = requests.get(url).text
+    r = requests.get(url)
+    data_text = r.text
     data_list = data_text[data_text.find('"') + 1 : data_text.rfind('"')].split(",")
     field_list = [
         "买量",
@@ -249,7 +263,8 @@ def option_sina_sse_underlying_spot_price(code: str = "sh510300") -> pd.DataFram
     :rtype: pandas.DataFrame
     """
     url = f"http://hq.sinajs.cn/list={code}"
-    data_text = requests.get(url).text
+    r = requests.get(url)
+    data_text = r.text
     data_list = data_text[data_text.find('"') + 1 : data_text.rfind('"')].split(",")
     field_list = [
         "证券简称",
@@ -290,7 +305,7 @@ def option_sina_sse_underlying_spot_price(code: str = "sh510300") -> pd.DataFram
     return data_df
 
 
-def option_sina_sse_greeks(code: str = "10002273") -> pd.DataFrame:
+def option_sina_sse_greeks(code: str = "10003045") -> pd.DataFrame:
     """
     期权基本信息表
     :param code: 合约代码
@@ -299,8 +314,9 @@ def option_sina_sse_greeks(code: str = "10002273") -> pd.DataFrame:
     :rtype: pandas.DataFrame
     """
     url = f"http://hq.sinajs.cn/list=CON_SO_{code}"
-    data_text = requests.get(url).text
-    data_list = data_text[data_text.find('"') + 1: data_text.rfind('"')].split(",")
+    r = requests.get(url)
+    data_text = r.text
+    data_list = data_text[data_text.find('"') + 1 : data_text.rfind('"')].split(",")
     field_list = [
         "期权合约简称",
         "成交量",
@@ -322,7 +338,7 @@ def option_sina_sse_greeks(code: str = "10002273") -> pd.DataFrame:
     return data_df
 
 
-def option_sina_sse_minute(code: str = "10002273") -> pd.DataFrame:
+def option_sina_sse_minute(code: str = "10003045") -> pd.DataFrame:
     """
     指定期权品种在当前交易日的分钟数据, 只能获取当前交易日的数据, 不能获取历史分钟数据
     https://stock.finance.sina.com.cn/option/quotes.html
@@ -331,33 +347,32 @@ def option_sina_sse_minute(code: str = "10002273") -> pd.DataFrame:
     :return: 指定期权的当前交易日的分钟数据
     :rtype: pandas.DataFrame
     """
-    url = (
-        f"https://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionDaylineService.getOptionMinline?"
-        f"symbol=CON_OP_{code}"
-    )
-    data_json = requests.get(url).json()["result"]["data"]
-    data_df = pd.DataFrame(data_json)
+    url = "https://stock.finance.sina.com.cn/futures/api/openapi.php/StockOptionDaylineService.getOptionMinline"
+    params = {"symbol": f"CON_OP_{code}"}
+    r = requests.get(url, params=params)
+    data_json = r.json()
+    temp_df = data_json["result"]["data"]
+    data_df = pd.DataFrame(temp_df)
     data_df.columns = ["时间", "价格", "成交", "持仓", "均价", "日期"]
     return data_df
 
 
 def option_sina_sse_daily(code: str = "10002273") -> pd.DataFrame:
     """
-    获取指定期权的日频率数据
+    指定期权的日频率数据
     :param code: 期权代码
     :type code: str
     :return: 指定期权的所有日频率历史数据
     :rtype: pandas.DataFrame
     """
-    url = (
-        f"http://stock.finance.sina.com.cn/futures/api/jsonp_v2.php//StockOptionDaylineService.getSymbolInfo?"
-        f"symbol=CON_OP_{code}"
-    )
-    data_text = requests.get(url).text
+    url = "http://stock.finance.sina.com.cn/futures/api/jsonp_v2.php//StockOptionDaylineService.getSymbolInfo"
+    params = {"symbol": f"CON_OP_{code}"}
+    r = requests.get(url, params=params)
+    data_text = r.text
     data_json = json.loads(data_text[data_text.find("(") + 1 : data_text.rfind(")")])
-    data_df = pd.DataFrame(data_json)
-    data_df.columns = ["日期", "开盘", "最高", "最低", "收盘", "成交"]
-    return data_df
+    temp_df = pd.DataFrame(data_json)
+    temp_df.columns = ["日期", "开盘", "最高", "最低", "收盘", "成交量"]
+    return temp_df
 
 
 def option_sina_finance_minute(code: str = "10002530") -> pd.DataFrame:
@@ -389,7 +404,7 @@ if __name__ == "__main__":
     option_sina_cffex_hs300_list_df = option_sina_cffex_hs300_list()
     print(option_sina_cffex_hs300_list_df)
 
-    option_sina_cffex_hs300_spot_df = option_sina_cffex_hs300_spot(contract="io2106")
+    option_sina_cffex_hs300_spot_df = option_sina_cffex_hs300_spot(contract="io2104")
     print(option_sina_cffex_hs300_spot_df)
 
     option_sina_cffex_hs300_daily_df = option_sina_cffex_hs300_daily(
@@ -402,17 +417,15 @@ if __name__ == "__main__":
     print(option_sina_sse_list_df)
 
     option_sina_sse_expire_day_df = option_sina_sse_expire_day(
-        trade_date="202101", symbol="50ETF", exchange="null"
+        trade_date="202102", symbol="50ETF", exchange="null"
     )
     print(option_sina_sse_expire_day_df)
 
-    up, down = option_sina_sse_codes(
-        trade_date="202012", underlying="510300"
-    )
+    up, down = option_sina_sse_codes(trade_date="202103", underlying="510300")
     print(up)
     print(down)
 
-    option_sina_sse_spot_price_df = option_sina_sse_spot_price(code="10002497")
+    option_sina_sse_spot_price_df = option_sina_sse_spot_price(code="10003045")
     print(option_sina_sse_spot_price_df)
 
     option_sina_sse_underlying_spot_price_df = option_sina_sse_underlying_spot_price(
@@ -420,14 +433,14 @@ if __name__ == "__main__":
     )
     print(option_sina_sse_underlying_spot_price_df)
 
-    option_sina_sse_greeks_df = option_sina_sse_greeks(code="10002498")
+    option_sina_sse_greeks_df = option_sina_sse_greeks(code="10003045")
     print(option_sina_sse_greeks_df)
 
-    option_sina_sse_minute_df = option_sina_sse_minute(code="10002498")
+    option_sina_sse_minute_df = option_sina_sse_minute(code="10003045")
     print(option_sina_sse_minute_df)
 
-    option_sina_sse_daily_df = option_sina_sse_daily(code="10002498")
+    option_sina_sse_daily_df = option_sina_sse_daily(code="10003045")
     print(option_sina_sse_daily_df)
 
-    option_sina_finance_minute_df = option_sina_finance_minute(code="10002498")
+    option_sina_finance_minute_df = option_sina_finance_minute(code="10003045")
     print(option_sina_finance_minute_df)
