@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/12/19 14:26
+Date: 2021/5/2 16:26
 Desc: 东方财富网-数据中心-资金流向
 http://data.eastmoney.com/zjlx/detail.html
 """
@@ -66,7 +66,7 @@ def stock_individual_fund_flow(
     return temp_df
 
 
-def stock_individual_fund_flow_rank(indicator: str = "今日") -> pd.DataFrame:
+def stock_individual_fund_flow_rank(indicator: str = "5日") -> pd.DataFrame:
     """
     东方财富网-数据中心-资金流向-排名
     http://data.eastmoney.com/zjlx/detail.html
@@ -76,71 +76,193 @@ def stock_individual_fund_flow_rank(indicator: str = "今日") -> pd.DataFrame:
     :rtype: pandas.DataFrame
     """
     indicator_map = {
-        "今日": ["f62", "1"],
-        "3日": ["f267", "3"],
-        "5日": ["f164", "5"],
-        "10日": ["f174", "10"],
+        "今日": ["f62", "f12,f14,f2,f3,f62,f184,f66,f69,f72,f75,f78,f81,f84,f87,f204,f205,f124"],
+        "3日": ["f267", "f12,f14,f2,f127,f267,f268,f269,f270,f271,f272,f273,f274,f275,f276,f257,f258,f124"],
+        "5日": ["f164", "f12,f14,f2,f109,f164,f165,f166,f167,f168,f169,f170,f171,f172,f173,f257,f258,f124"],
+        "10日": ["f174", "f12,f14,f2,f160,f174,f175,f176,f177,f178,f179,f180,f181,f182,f183,f260,f261,f124"],
     }
     url = "http://push2.eastmoney.com/api/qt/clist/get"
     params = {
-        "pn": "1",
-        "pz": "5000",
-        "po": "1",
-        "np": "1",
-        "ut": "b2884a393a59ad64002292a3e90d46a5",
-        "fltt": "2",
-        "invt": "2",
-        "fid0": "f4001",
-        "fid": indicator_map[indicator][0],
-        "fs": "m:0 t:6 f:!2,m:0 t:13 f:!2,m:0 t:80 f:!2,m:1 t:2 f:!2,m:1 t:23 f:!2,m:0 t:7 f:!2,m:1 t:3 f:!2",
-        "stat": indicator_map[indicator][1],
-        "fields": "f12,f14,f2,f3,f62,f184,f66,f69,f72,f75,f78,f81,f84,f87,f204,f205,f124",
-        "rt": "52975151",
-        "cb": "jQuery18303745396043640481_1589254432189",
-        "_": int(time.time() * 1000),
+        'fid': indicator_map[indicator][0],
+        'po': '1',
+        'pz': '5000',
+        'pn': '1',
+        'np': '1',
+        'fltt': '2',
+        'invt': '2',
+        'ut': 'b2884a393a59ad64002292a3e90d46a5',
+        'fs': 'm:0+t:6+f:!2,m:0+t:13+f:!2,m:0+t:80+f:!2,m:1+t:2+f:!2,m:1+t:23+f:!2,m:0+t:7+f:!2,m:1+t:3+f:!2',
+        'fields': indicator_map[indicator][1]
     }
     r = requests.get(url, params=params)
-    text_data = r.text
-    json_data = json.loads(text_data[text_data.find("{") : -2])
-    temp_df = pd.DataFrame(json_data["data"]["diff"])
-    temp_df.columns = [
-        "最新价",
-        "涨跌幅",
-        "代码",
-        "名称",
-        "主力净流入-净额",
-        "超大单净流入-净额",
-        "超大单净流入-净占比",
-        "大单净流入-净额",
-        "大单净流入-净占比",
-        "中单净流入-净额",
-        "中单净流入-净占比",
-        "小单净流入-净额",
-        "小单净流入-净占比",
-        "-",
-        "主力净流入-净占比",
-        "-",
-        "-",
-        "-",
-    ]
-    temp_df = temp_df[
-        [
+    data_json = r.json()
+    temp_df = pd.DataFrame(data_json["data"]["diff"])
+    temp_df.reset_index(inplace=True)
+    temp_df['index'] = range(1, len(temp_df)+1)
+    if indicator == "今日":
+        temp_df.columns = [
+            "序号",
             "最新价",
-            "涨跌幅",
+            "今日涨跌幅",
             "代码",
             "名称",
-            "主力净流入-净额",
-            "主力净流入-净占比",
-            "超大单净流入-净额",
-            "超大单净流入-净占比",
-            "大单净流入-净额",
-            "大单净流入-净占比",
-            "中单净流入-净额",
-            "中单净流入-净占比",
-            "小单净流入-净额",
-            "小单净流入-净占比",
+            "今日主力净流入-净额",
+            "今日超大单净流入-净额",
+            "今日超大单净流入-净占比",
+            "今日大单净流入-净额",
+            "今日大单净流入-净占比",
+            "今日中单净流入-净额",
+            "今日中单净流入-净占比",
+            "今日小单净流入-净额",
+            "今日小单净流入-净占比",
+            "_",
+            "今日主力净流入-净占比",
+            "_",
+            "_",
+            "_",
+        ]
+        temp_df = temp_df[
+            [
+                "序号",
+                "代码",
+                "名称",
+                "最新价",
+                "今日涨跌幅",
+                "今日主力净流入-净额",
+                "今日主力净流入-净占比",
+                "今日超大单净流入-净额",
+                "今日超大单净流入-净占比",
+                "今日大单净流入-净额",
+                "今日大单净流入-净占比",
+                "今日中单净流入-净额",
+                "今日中单净流入-净占比",
+                "今日小单净流入-净额",
+                "今日小单净流入-净占比",
+            ]
+        ]
+    elif indicator == "3日":
+        temp_df.columns = [
+            "序号",
+            "最新价",
+            "代码",
+            "名称",
+            "_",
+            "3日涨跌幅",
+            "_",
+            "_",
+            "_",
+            "3日主力净流入-净额",
+            "3日主力净流入-净占比",
+            "3日超大单净流入-净额",
+            "3日超大单净流入-净占比",
+            "3日大单净流入-净额",
+            "3日大单净流入-净占比",
+            "3日中单净流入-净额",
+            "3日中单净流入-净占比",
+            "3日小单净流入-净额",
+            "3日小单净流入-净占比",
+        ]
+        temp_df = temp_df[
+            [
+                "序号",
+                "代码",
+                "名称",
+                "最新价",
+                "3日涨跌幅",
+                "3日主力净流入-净额",
+                "3日主力净流入-净占比",
+                "3日超大单净流入-净额",
+                "3日超大单净流入-净占比",
+                "3日大单净流入-净额",
+                "3日大单净流入-净占比",
+                "3日中单净流入-净额",
+                "3日中单净流入-净占比",
+                "3日小单净流入-净额",
+                "3日小单净流入-净占比",
+            ]
+        ]
+    elif indicator == "5日":
+        temp_df.columns = [
+            "序号",
+            "最新价",
+            "代码",
+            "名称",
+            "5日涨跌幅",
+            "_",
+            "5日主力净流入-净额",
+            "5日主力净流入-净占比",
+            "5日超大单净流入-净额",
+            "5日超大单净流入-净占比",
+            "5日大单净流入-净额",
+            "5日大单净流入-净占比",
+            "5日中单净流入-净额",
+            "5日中单净流入-净占比",
+            "5日小单净流入-净额",
+            "5日小单净流入-净占比",
+            "_",
+            "_",
+            "_",
+        ]
+        temp_df = temp_df[
+            [
+                "序号",
+                "代码",
+                "名称",
+                "最新价",
+                "5日涨跌幅",
+                "5日主力净流入-净额",
+                "5日主力净流入-净占比",
+                "5日超大单净流入-净额",
+                "5日超大单净流入-净占比",
+                "5日大单净流入-净额",
+                "5日大单净流入-净占比",
+                "5日中单净流入-净额",
+                "5日中单净流入-净占比",
+                "5日小单净流入-净额",
+                "5日小单净流入-净占比",
+            ]
+        ]
+    elif indicator == "10日":
+        temp_df.columns = [
+            "序号",
+            "最新价",
+            "代码",
+            "名称",
+            "_",
+            "10日涨跌幅",
+            "10日主力净流入-净额",
+            "10日主力净流入-净占比",
+            "10日超大单净流入-净额",
+            "10日超大单净流入-净占比",
+            "10日大单净流入-净额",
+            "10日大单净流入-净占比",
+            "10日中单净流入-净额",
+            "10日中单净流入-净占比",
+            "10日小单净流入-净额",
+            "10日小单净流入-净占比",
+            "_",
+            "_",
+            "_",
+        ]
+        temp_df = temp_df[
+            [
+                "序号",
+                "代码",
+                "名称",
+                "最新价",
+                "10日涨跌幅",
+                "10日主力净流入-净额",
+                "10日主力净流入-净占比",
+                "10日超大单净流入-净额",
+                "10日超大单净流入-净占比",
+                "10日大单净流入-净额",
+                "10日大单净流入-净占比",
+                "10日中单净流入-净额",
+                "10日中单净流入-净占比",
+                "10日小单净流入-净额",
+                "10日小单净流入-净占比",
+            ]
         ]
-    ]
     return temp_df
 
 
@@ -403,6 +525,21 @@ if __name__ == "__main__":
     )
     print(stock_individual_fund_flow_df)
 
+    stock_individual_fund_flow_rank_df = stock_individual_fund_flow_rank(
+        indicator="今日"
+    )
+    print(stock_individual_fund_flow_rank_df)
+
+    stock_individual_fund_flow_rank_df = stock_individual_fund_flow_rank(
+        indicator="3日"
+    )
+    print(stock_individual_fund_flow_rank_df)
+
+    stock_individual_fund_flow_rank_df = stock_individual_fund_flow_rank(
+        indicator="5日"
+    )
+    print(stock_individual_fund_flow_rank_df)
+
     stock_individual_fund_flow_rank_df = stock_individual_fund_flow_rank(
         indicator="10日"
     )
